UnfilterBuf

Struct UnfilterBuf 

pub struct UnfilterBuf<'data> {
    pub(crate) buffer: &'data mut [u8],
    pub(crate) available: &'data mut usize,
    pub(crate) filled: &'data mut usize,
}
A buffer for decompression and in-place filtering of PNG rowlines.

The underlying data structure is a vector, with additional markers dividing the vector into specific regions of bytes - see UnfilterRegion for more details.

Fields

buffer: &'data mut [u8]

The data container.

available: &'data mut usize

The past-the-end index of the region that is allowed to be modified.

filled: &'data mut usize

The past-the-end index of the region with decompressed bytes.

Implementations

Source

impl UnfilterBuf<'_>

fn decompress( &mut self, decompressor: &mut Decompressor, input: &[u8], ) -> Result<usize, DecodingError>

Pushes input into fdeflate crate and appends decompressed bytes to self.buffer (adjusting self.filled and self.available depending on how many bytes have been decompressed).

Returns how many bytes of input have been consumed.