UnfilterRegion

Struct UnfilterRegion 

pub struct UnfilterRegion {
    pub available: usize,
    pub filled: usize,
}
UnfilterRegion divides a Vec<u8> buffer into three consecutive regions:

  • vector[0..available] - bytes that may be mutated (this typically means bytes that were decompressed earlier, but user of the buffer may also use this region for storing other data)
  • vector[available..filled] - already decompressed bytes that need to be preserved. (Future decompressor calls may reference and copy bytes from this region. The maximum filled - available “look back” distance for PNG compression method 0 is 32768 bytes)
  • vector[filled..] - buffer where future decompressor calls can write additional decompressed bytes

Even though only vector[0..available] bytes can be mutated, it is allowed to “shift” or “move” the contents of vector, as long as the:

  • vector[available..filled] bytes are preserved
  • available and filled offsets are updated

Violating the invariants described above (e.g. mutating the bytes in the vector[available..filled] region) may result in absurdly wacky decompression output or panics, but not undefined behavior.

Fields

available: usize

The past-the-end index of the region that is allowed to be modified.

filled: usize

The past-the-end index of the region with decompressed bytes.

Implementations

Source

impl UnfilterRegion

pub fn as_buf<'data>( &'data mut self, buffer: &'data mut Vec<u8>, ) -> UnfilterBuf<'data>

Use this region to decompress new filtered rowline data.

Pass the wrapped buffer to StreamingDecoder::update to fill it with data and update the region indices.

May panic if invariants of UnfilterRegion are violated.